@@ -22,29 +22,46 @@
 #' @param tbl a \code{data.frame} containing isolates.
 #' @param col_date column name of the result date (or date that is was received on the lab)
 #' @param col_patient_id column name of the unique IDs of the patients
-#' @param col_genus column name of the genus of the microorganisms
-#' @param col_species column name of the species of the microorganisms
-#' @param col_testcode column name of the test codes. Use \code{col_testcode = NA} to \strong{not} exclude certain test codes (like test codes for screening). In that case \code{testcodes_exclude} will be ignored.
+#' @param col_bactid column name of the unique IDs of the microorganisms (should occur in the \code{\link{microorganisms}} dataset)
+#' @param col_testcode column name of the test codes. Use \code{col_testcode = NA} to \strong{not} exclude certain test codes (like test codes for screening). In that case \code{testcodes_exclude} will be ignored. Supports tidyverse-like quotation.
 #' @param col_specimen column name of the specimen type or group
 #' @param col_icu column name of the logicals (\code{TRUE}/\code{FALSE}) whether a ward or department is an Intensive Care Unit (ICU)
-#' @param col_keyantibiotics column name of the key antibiotics to determine first \emph{weighted} isolates, see \code{\link{key_antibiotics}}.
+#' @param col_keyantibiotics column name of the key antibiotics to determine first \emph{weighted} isolates, see \code{\link{key_antibiotics}}. Supports tidyverse-like quotation.
 #' @param episode_days episode in days after which a genus/species combination will be determined as 'first isolate' again
-#' @param testcodes_exclude character vector with test codes that should be excluded (caseINsensitive)
+#' @param testcodes_exclude character vector with test codes that should be excluded (case-insensitive)
 #' @param icu_exclude logical whether ICU isolates should be excluded
 #' @param filter_specimen specimen group or type that should be excluded
-#' @param output_logical return output as \code{logical} (will else the values \code{0} or \code{1})
-#' @param points_threshold points until the comparison of key antibiotics will lead to inclusion of an isolate, see Details
+#' @param output_logical return output as \code{logical} (will else be the values \code{0} or \code{1})
+#' @param type type to determine weighed isolates; can be \code{"keyantibiotics"} or \code{"points"}, see Details
+#' @param ignore_I logical to determine whether antibiotic interpretations with \code{"I"} will be ignored when \code{type = "keyantibiotics"}, see Details
+#' @param points_threshold points until the comparison of key antibiotics will lead to inclusion of an isolate when \code{type = "points"}, see Details
 #' @param info print progress
-#' @details \strong{Why this is so important} \cr
+#' @param col_genus (deprecated, use \code{col_bactid} instead) column name of the genus of the microorganisms
+#' @param col_species (deprecated, use \code{col_bactid} instead) column name of the species of the microorganisms
+#' @details \strong{WHY THIS IS SO IMPORTANT} \cr
 #'     To conduct an analysis of antimicrobial resistance, you should only include the first isolate of every patient per episode \href{https://www.ncbi.nlm.nih.gov/pubmed/17304462}{[1]}. If you would not do this, you could easily get an overestimate or underestimate of the resistance of an antibiotic. Imagine that a patient was admitted with an MRSA and that it was found in 5 different blood cultures the following week. The resistance percentage of oxacillin of all \emph{S. aureus} isolates would be overestimated, because you included this MRSA more than once. It would be \href{https://en.wikipedia.org/wiki/Selection_bias}{selection bias}.
 #'
-#'     \strong{Using parameter \code{points_threshold}} \cr
-#'     To compare key antibiotics, the difference between antimicrobial interpretations will be measured. A difference from I to S|R (or vice versa) means 0.5 points. A difference from S to R (or vice versa) means 1 point. When the sum of points exceeds \code{points_threshold}, an isolate will be (re)selected as a first weighted isolate.
+#'     \strong{DETERMINING WEIGHTED ISOLATES} \cr
+#'     \strong{1. Using} \code{type = "keyantibiotics"} \strong{and parameter} \code{ignore_I} \cr
+#'     To determine weighted isolates, the difference between key antibiotics will be checked. Any difference from S to R (or vice versa) will (re)select an isolate as a first weighted isolate. With \code{ignore_I = FALSE}, also differences from I to S|R (or vice versa) will lead to this. This is a reliable method and 30-35 times faster than method 2. \cr
+#'     \strong{2. Using} \code{type = "points"} \strong{and parameter} \code{points_threshold} \cr
+#'     To determine weighted isolates, difference between antimicrobial interpretations will be measured with points. A difference from I to S|R (or vice versa) means 0.5 points, a difference from S to R (or vice versa) means 1 point. When the sum of points exceeds \code{points_threshold}, an isolate will be (re)selected as a first weighted isolate. This method is being used by the Infection Prevention department (Dr M. Lokate) of the University Medical Center Groningen (UMCG).
 #' @keywords isolate isolates first
 #' @export
 #' @importFrom dplyr arrange_at lag between row_number filter mutate arrange
 #' @return A vector to add to table, see Examples.
+#' @source Methodology of this function is based on: "M39 Analysis and Presentation of Cumulative Antimicrobial Susceptibility Test Data, 4th Edition", 2014, Clinical and Laboratory Standards Institute. \url{https://clsi.org/standards/products/microbiology/documents/m39/}.
 #' @examples
+#' # septic_patients is a dataset available in the AMR package
+#' ?septic_patients
+#' my_patients <- septic_patients
+#'
+#' library(dplyr)
+#' my_patients$first_isolate <- my_patients %>%
+#'   first_isolate(col_date = "date",
+#'                 col_patient_id = "patient_id",
+#'                 col_bactid = "bactid")
+#'
 #' \dontrun{
 #'
 #' # set key antibiotics to a new variable
@@ -87,59 +104,78 @@
 first_isolate <- function(tbl,
                           col_date,
                           col_patient_id,
-                          col_genus,
-                          col_species,
+                          col_bactid = NA,
                           col_testcode = NA,
-                          col_specimen,
-                          col_icu,
+                          col_specimen = NA,
+                          col_icu = NA,
                           col_keyantibiotics = NA,
                           episode_days = 365,
                           testcodes_exclude = '',
                           icu_exclude = FALSE,
                           filter_specimen = NA,
                           output_logical = TRUE,
+                          type = "keyantibiotics",
+                          ignore_I = TRUE,
                           points_threshold = 2,
-                          info = TRUE) {
-  
-  # controleren of kolommen wel bestaan
+                          info = TRUE,
+                          col_genus = NA,
+                          col_species = NA) {
+
+  # bactid OR genus+species must be available
+  if (is.na(col_bactid) & (is.na(col_genus) | is.na(col_species))) {
+    stop('`col_bactid or both `col_genus` and `col_species` must be available.')
+  }
+
+  # check if columns exist
   check_columns_existance <- function(column, tblname = tbl) {
     if (NROW(tblname) <= 1 | NCOL(tblname) <= 1) {
       stop('Please check tbl for existance.')
     }
-    
+
     if (!is.na(column)) {
       if (!(column %in% colnames(tblname))) {
-        stop('Column ', column, ' not found.')
+        stop('Column `', column, '` not found.')
       }
     }
   }
-  
+
   check_columns_existance(col_date)
   check_columns_existance(col_patient_id)
+  check_columns_existance(col_bactid)
   check_columns_existance(col_genus)
   check_columns_existance(col_species)
   check_columns_existance(col_testcode)
   check_columns_existance(col_icu)
   check_columns_existance(col_keyantibiotics)
-  
+
+  if (!is.na(col_bactid)) {
+    tbl <- tbl %>% left_join_microorganisms(by = col_bactid)
+    col_genus <- "genus"
+    col_species <- "species"
+  }
+
   if (is.na(col_testcode)) {
     testcodes_exclude <- NA
   }
-  # testcodes verwijderen die ingevuld zijn
+  # remove testcodes
   if (!is.na(testcodes_exclude[1]) & testcodes_exclude[1] != '' & info == TRUE) {
     cat('Isolates from these test codes will be ignored:\n', toString(testcodes_exclude), '\n')
   }
-  
+
   if (is.na(col_icu)) {
     icu_exclude <- FALSE
   } else {
     tbl <- tbl %>%
       mutate(col_icu = tbl %>% pull(col_icu) %>% as.logical())
   }
-  
+
+  if (is.na(col_specimen)) {
+    filter_specimen <- ''
+  }
+
   specgroup.notice <- ''
   weighted.notice <- ''
-  # filteren op materiaalgroep en sleutelantibiotica gebruiken wanneer deze ingevuld zijn
+  # filter on specimen group and keyantibiotics when they are filled in
   if (!is.na(filter_specimen) & filter_specimen != '') {
     check_columns_existance(col_specimen, tbl)
     if (info == TRUE) {
@@ -153,13 +189,12 @@ first_isolate <- function(tbl,
   } else {
     tbl <- tbl %>% mutate(key_ab = tbl %>% pull(col_keyantibiotics))
   }
-  
+
   if (is.na(testcodes_exclude[1])) {
     testcodes_exclude <- ''
   }
-  
-  # nieuwe dataframe maken met de oorspronkelijke rij-index, 0-bepaling en juiste sortering
-  #cat('Sorting table...')
+
+  # create new dataframe with original row index and right sorting
   tbl <- tbl %>%
     mutate(first_isolate_row_index = 1:nrow(tbl),
            eersteisolaatbepaling = 0,
@@ -169,9 +204,9 @@ first_isolate <- function(tbl,
            genus = tbl %>% pull(col_genus)) %>%
     mutate(species = if_else(is.na(species), '', species),
            genus = if_else(is.na(genus), '', genus))
-  
+
   if (filter_specimen == '') {
-    
+
     if (icu_exclude == FALSE) {
       if (info == TRUE) {
         cat('Isolates from ICU will *NOT* be ignored.\n')
@@ -193,7 +228,7 @@ first_isolate <- function(tbl,
                      col_genus,
                      col_species,
                      col_date))
-      
+
       suppressWarnings(
         row.start <- which(tbl %>% pull(col_icu) == FALSE) %>% min(na.rm = TRUE)
       )
@@ -201,9 +236,9 @@ first_isolate <- function(tbl,
         row.end <- which(tbl %>% pull(col_icu) == FALSE) %>% max(na.rm = TRUE)
       )
     }
-    
+
   } else {
-    # sorteren op materiaal en alleen die rijen analyseren om tijd te besparen
+    # sort on specimen and only analyse these row to save time
     if (icu_exclude == FALSE) {
       if (info == TRUE) {
         cat('Isolates from ICU will *NOT* be ignored.\n')
@@ -240,14 +275,14 @@ first_isolate <- function(tbl,
                          & tbl %>% pull(col_icu) == FALSE) %>% max(na.rm = TRUE)
       )
     }
-    
+
   }
-  
+
   if (abs(row.start) == Inf | abs(row.end) == Inf) {
     if (info == TRUE) {
       cat('No isolates found.\n')
     }
-    # NA's maken waar genus niet beschikbaar is
+    # NA's where genus is unavailable
     tbl <- tbl %>%
       mutate(real_first_isolate = if_else(genus == '', NA, FALSE))
     if (output_logical == FALSE) {
@@ -255,15 +290,15 @@ first_isolate <- function(tbl,
     }
     return(tbl %>% pull(real_first_isolate))
   }
-  
+
   scope.size <- tbl %>%
     filter(row_number() %>%
              between(row.start,
                      row.end),
            genus != '') %>%
     nrow()
-  
-  # Analyse van eerste isolaat ----
+
+  # Analysis of first isolate ----
   all_first <- tbl %>%
     mutate(other_pat_or_mo = if_else(patient_id == lag(patient_id)
                                      & genus == lag(genus)
@@ -274,16 +309,28 @@ first_isolate <- function(tbl,
     mutate(days_diff = if_else(other_pat_or_mo == FALSE,
                                (date_lab - lag(date_lab)) + lag(days_diff),
                                0))
-  
+
   if (col_keyantibiotics != '') {
     if (info == TRUE) {
-      cat(paste0('Comparing key antibiotics for first weighted isolates (using points threshold of '
-                 , points_threshold, ')...\n'))
+      if (type == 'keyantibiotics') {
+        cat('Comparing key antibiotics for first weighted isolates (')
+        if (ignore_I == FALSE) {
+          cat('NOT ')
+        }
+        cat('ignoring I)...\n')
+      }
+      if (type == 'points') {
+        cat(paste0('Comparing antibiotics for first weighted isolates (using points threshold of '
+                   , points_threshold, ')...\n'))
+      }
     }
+    type_param <- type
     all_first <- all_first %>%
       mutate(key_ab_lag = lag(key_ab)) %>%
       mutate(key_ab_other = !key_antibiotics_equal(x = key_ab,
                                                    y = key_ab_lag,
+                                                   type = type_param,
+                                                   ignore_I = ignore_I,
                                                    points_threshold = points_threshold,
                                                    info = info)) %>%
       mutate(
@@ -311,25 +358,25 @@ first_isolate <- function(tbl,
             TRUE,
             FALSE))
   }
-  
-  # allereerst isolaat als TRUE
+
+  # first one as TRUE
   all_first[row.start, 'real_first_isolate'] <- TRUE
-  # geen testen die uitgesloten moeten worden, of ICU
+  # no tests that should be included, or ICU
   if (!is.na(col_testcode)) {
     all_first[which(all_first[, col_testcode] %in% tolower(testcodes_exclude)), 'real_first_isolate'] <- FALSE
   }
   if (icu_exclude == TRUE) {
     all_first[which(all_first[, col_icu] == TRUE), 'real_first_isolate'] <- FALSE
   }
-  
-  # NA's maken waar genus niet beschikbaar is
+
+  # NA's where genus is unavailable
   all_first <- all_first %>%
     mutate(real_first_isolate = if_else(genus == '', NA, real_first_isolate))
-  
+
   all_first <- all_first %>%
     arrange(first_isolate_row_index) %>%
     pull(real_first_isolate)
-  
+
   if (info == TRUE) {
     cat(paste0('\nFound ',
                all_first %>% sum(na.rm = TRUE),
@@ -339,32 +386,32 @@ first_isolate <- function(tbl,
                (all_first %>% sum(na.rm = TRUE) / tbl %>% nrow()) %>% percent(),
                ' of total)\n'))
   }
-  
+
   if (output_logical == FALSE) {
     all_first <- all_first %>% as.integer()
   }
-  
+
   all_first
-  
+
 }
 
 #' Key antibiotics based on bacteria ID
 #'
 #' @param tbl table with antibiotics coloms, like \code{amox} and \code{amcl}.
-#' @param col_bactcode column of bacteria IDs in \code{tbl}; these should occur in \code{bactlist$bactid}, see \code{\link{bactlist}}
+#' @param col_bactid column of bacteria IDs in \code{tbl}; these should occur in \code{microorganisms$bactid}, see \code{\link{microorganisms}}
 #' @param info print warnings
-#' @param amcl,amox,cfot,cfta,cftr,cfur,cipr,clar,clin,clox,doxy,gent,line,mero,peni,pita,rifa,teic,trsu,vanc column names of antibiotics.
+#' @param amcl,amox,cfot,cfta,cftr,cfur,cipr,clar,clin,clox,doxy,gent,line,mero,peni,pita,rifa,teic,trsu,vanc column names of antibiotics, case-insensitive
 #' @export
-#' @importFrom dplyr %>% mutate if_else 
+#' @importFrom dplyr %>% mutate if_else
 #' @return Character of length 1.
-#' @seealso \code{\link{mo_property}} \code{\link{ablist}}
-#' @examples 
+#' @seealso \code{\link{mo_property}} \code{\link{antibiotics}}
+#' @examples
 #' \donttest{
 #' #' # set key antibiotics to a new variable
 #' tbl$keyab <- key_antibiotics(tbl)
 #' }
 key_antibiotics <- function(tbl,
-                            col_bactcode = 'bactid',
+                            col_bactid = 'bactid',
                             info = TRUE,
                             amcl = 'amcl',
                             amox = 'amox',
@@ -386,28 +433,43 @@ key_antibiotics <- function(tbl,
                             teic = 'teic',
                             trsu = 'trsu',
                             vanc = 'vanc') {
-  
+
   keylist <- character(length = nrow(tbl))
-  
+
+  if (!col_bactid %in% colnames(tbl)) {
+    stop('Column ', col_bactid, ' not found.', call. = FALSE)
+  }
+
   # check columns
   col.list <- c(amox, cfot, cfta, cftr, cfur, cipr, clar,
                 clin, clox, doxy, gent, line, mero, peni,
                 pita, rifa, teic, trsu, vanc)
-  col.list <- col.list[!is.na(col.list)]
-  if (!all(col.list %in% colnames(tbl))) {
-    if (info == TRUE) {
-      warning('These columns do not exist and will be ignored:\n',
-              col.list[!(col.list %in% colnames(tbl))] %>% toString(),
-              immediate. = TRUE,
-              call. = FALSE)
-    }
-  }
-  
-  # bactlist aan vastknopen
-  tbl <- tbl %>% left_join_bactlist(col_bactcode)
-  
+  col.list <- check_available_columns(tbl = tbl, col.list = col.list, info = info)
+  amox <- col.list[amox]
+  cfot <- col.list[cfot]
+  cfta <- col.list[cfta]
+  cftr <- col.list[cftr]
+  cfur <- col.list[cfur]
+  cipr <- col.list[cipr]
+  clar <- col.list[clar]
+  clin <- col.list[clin]
+  clox <- col.list[clox]
+  doxy <- col.list[doxy]
+  gent <- col.list[gent]
+  line <- col.list[line]
+  mero <- col.list[mero]
+  peni <- col.list[peni]
+  pita <- col.list[pita]
+  rifa <- col.list[rifa]
+  teic <- col.list[teic]
+  trsu <- col.list[trsu]
+  vanc <- col.list[vanc]
+
+  # join microorganisms
+  tbl <- tbl %>% left_join_microorganisms(col_bactid)
+
   tbl$key_ab <- NA_character_
-  
+
   # Staphylococcus
   list_ab <- c(clox, trsu, teic, vanc, doxy, line, clar, rifa)
   list_ab <- list_ab[list_ab %in% colnames(tbl)]
@@ -417,84 +479,116 @@ key_antibiotics <- function(tbl,
                                         MARGIN = 1,
                                         FUN = function(x) paste(x, collapse = "")),
                                   key_ab))
-  
+
   # Rest of Gram +
   list_ab <- c(peni, amox, teic, vanc, clin, line, clar, trsu)
   list_ab <- list_ab[list_ab %in% colnames(tbl)]
   tbl <- tbl %>% mutate(key_ab =
-                          if_else(gramstain %like% '^Positi[e]?ve',
+                          if_else(gramstain %like% '^Positive ',
                                   apply(X = tbl[, list_ab],
                                         MARGIN = 1,
                                         FUN = function(x) paste(x, collapse = "")),
                                   key_ab))
-  
+
   # Gram -
   list_ab <- c(amox, amcl, pita, cfur, cfot, cfta, cftr, mero, cipr, trsu, gent)
   list_ab <- list_ab[list_ab %in% colnames(tbl)]
   tbl <- tbl %>% mutate(key_ab =
-                          if_else(gramstain %like% '^Negati[e]?ve',
+                          if_else(gramstain %like% '^Negative ',
                                   apply(X = tbl[, list_ab],
                                         MARGIN = 1,
                                         FUN = function(x) paste(x, collapse = "")),
                                   key_ab))
-  
+
   # format
   tbl <- tbl %>%
     mutate(key_ab = gsub('(NA|NULL)', '-', key_ab) %>% toupper())
-  
+
   tbl$key_ab
-  
+
 }
 
 #' @importFrom dplyr progress_estimated %>%
 #' @noRd
-key_antibiotics_equal <- function(x, y, points_threshold = 2, info = FALSE) {
+key_antibiotics_equal <- function(x,
+                                  y,
+                                  type = c("keyantibiotics", "points"),
+                                  ignore_I = TRUE,
+                                  points_threshold = 2,
+                                  info = FALSE) {
   # x is active row, y is lag
 
+  type <- type[1]
+
   if (length(x) != length(y)) {
     stop('Length of `x` and `y` must be equal.')
   }
-  
+
   result <- logical(length(x))
-  
+
   if (info == TRUE) {
     p <- dplyr::progress_estimated(length(x))
   }
-  
+
   for (i in 1:length(x)) {
-    
+
     if (info == TRUE) {
       p$tick()$print()
     }
-    
+
     if (is.na(x[i])) {
       x[i] <- ''
     }
     if (is.na(y[i])) {
       y[i] <- ''
     }
-    
-    if (nchar(x[i]) != nchar(y[i])) {
-      
-      result[i] <- FALSE
-      
-    } else if (x[i] == '' & y[i] == '') {
-      
-      result[i] <- TRUE
-      
-    } else {
-      
-      # count points for every single character:
-      # - no change is 0 points
-      # - I <-> S|R is 0.5 point
-      # - S|R <-> R|S is 1 point
-      # use the levels of as.rsi (S = 1, I = 2, R = 3)
 
-      x2 <- strsplit(x[i], "")[[1]] %>% as.rsi() %>% as.double()
-      y2 <- strsplit(y[i], "")[[1]] %>% as.rsi() %>% as.double()
-      
-      points <- (x2 - y2) %>% abs() %>% sum(na.rm = TRUE)
-      result[i] <- ((points / 2) >= points_threshold)
+    if (nchar(x[i]) != nchar(y[i])) {
+
+      result[i] <- FALSE
+
+    } else if (x[i] == '' & y[i] == '') {
+
+      result[i] <- TRUE
+
+    } else {
+
+      x2 <- strsplit(x[i], "")[[1]]
+      y2 <- strsplit(y[i], "")[[1]]
+
+      if (type == 'points') {
+        # count points for every single character:
+        # - no change is 0 points
+        # - I <-> S|R is 0.5 point
+        # - S|R <-> R|S is 1 point
+        # use the levels of as.rsi (S = 1, I = 2, R = 3)
+
+        suppressWarnings(x2 <- x2 %>% as.rsi() %>% as.double())
+        suppressWarnings(y2 <- y2 %>% as.rsi() %>% as.double())
+
+        points <- (x2 - y2) %>% abs() %>% sum(na.rm = TRUE)
+        result[i] <- ((points / 2) >= points_threshold)
+
+      } else if (type == 'keyantibiotics') {
+        # check if key antibiotics are exactly the same
+        # also possible to ignore I, so only S <-> R and S <-> R are counted
+        if (ignore_I == TRUE) {
+          valid_chars <- c('S', 's', 'R', 'r')
+        } else {
+          valid_chars <- c('S', 's', 'I', 'i', 'R', 'r')
+        }
+
+        # remove invalid values (like "-", NA) on both locations
+        x2[which(!x2 %in% valid_chars)] <- '?'
+        x2[which(!y2 %in% valid_chars)] <- '?'
+        y2[which(!x2 %in% valid_chars)] <- '?'
+        y2[which(!y2 %in% valid_chars)] <- '?'
+
+        result[i] <- all(x2 == y2)
+
+      } else {
+        stop('`', type, '` is not a valid value for type, must be "points" or "keyantibiotics". See ?first_isolate.')
+      }
     }
   }
   if (info == TRUE) {
